@@ -10,7 +10,7 @@
 use 5.014;
 use utf8;
 package App::SpreadRevolutionaryDate::Config;
-$App::SpreadRevolutionaryDate::Config::VERSION = '0.22';
+$App::SpreadRevolutionaryDate::Config::VERSION = '0.23';
 # ABSTRACT: Companion class of L<App::SpreadRevolutionaryDate>, to handle configuration file and command line arguments, subclass of L<AppConfig>.
 
 use Moose;
@@ -26,6 +26,13 @@ use Class::Load ':all';
 use Locale::TextDomain 'App-SpreadRevolutionaryDate';
 use namespace::autoclean;
 
+BEGIN {
+  unless ($ENV{PERL_UNICODE} && $ENV{PERL_UNICODE} =~ /A/) {
+    use Encode qw(decode_utf8);
+    @ARGV = map { decode_utf8($_, 1) } @ARGV;
+  }
+}
+
 
 sub new {
   my ($class, $filename) = @_;
@@ -302,7 +309,12 @@ sub get_msgmaker_arguments {
         && $self->acab;
 
   # Do not prompt if PromptUser default is set
-  $ENV{PERL_MM_USE_DEFAULT} = 1 if $msgmaker_args{default};
+  if ($msgmaker eq 'PromptUser') {
+    require App::SpreadRevolutionaryDate::MsgMaker::PromptUser;
+    if ($msgmaker_args{default} && $msgmaker_args{default} ne App::SpreadRevolutionaryDate::MsgMaker::PromptUser->meta->get_attribute('default')->default) {
+      $ENV{PERL_MM_USE_DEFAULT} = 1
+    }
+  }
 
   return %msgmaker_args;
 }
@@ -364,7 +376,7 @@ App::SpreadRevolutionaryDate::Config - Companion class of L<App::SpreadRevolutio
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 METHODS
 
